@@ -543,11 +543,24 @@ class SBatchStage(Stage):
     script_path: RelativeChildPathString
     args: list[str] = []
     sbatch_options: list[str] = []
+    log_path: str | None = None
     log_storage: Literal["git", "dvc"] | None = "git"
 
     @property
     def log_output(self) -> PathOutput:
-        log_path = f".calkit/slurm/logs/{self.name}.out"
+        log_path = self.log_path
+        if log_path is None:
+            log_path = f".calkit/slurm/logs/{self.name}"
+            if self.iterate_over is not None:
+                arg_names = []
+                for item in self.iterate_over:
+                    if isinstance(item.arg_name, list):
+                        arg_names += item.arg_name
+                    else:
+                        arg_names.append(item.arg_name)
+                for arg_name in arg_names:
+                    log_path += f"/{{{arg_name}}}"
+            log_path += ".out"
         return PathOutput(
             path=log_path,
             storage=self.log_storage,
@@ -583,8 +596,20 @@ class SBatchStage(Stage):
     @property
     def dvc_cmd(self) -> str:
         cmd = f"calkit slurm batch --name {self.name}"
+        if self.iterate_over is not None:
+            arg_names = []
+            for item in self.iterate_over:
+                if isinstance(item.arg_name, list):
+                    arg_names += item.arg_name
+                else:
+                    arg_names.append(item.arg_name)
+            cmd += "@" + ",".join(
+                [f"{{{arg_name}}}" for arg_name in arg_names]
+            )
         if self.environment != "_system":
             cmd += f" --environment {self.environment}"
+        if self.log_path is not None:
+            cmd += f" --log-path '{self.log_path}'"
         for dep in self.dvc_deps:
             if dep != self.script_path:
                 cmd += f" --dep {dep}"
